@@ -1,4 +1,4 @@
-from lndb_setup import settings
+from lndb import settings
 from lnschema_core.dev.sqlmodel import schema_sqlmodel
 from sqlmodel import Field
 
@@ -15,9 +15,7 @@ if "wetlab" in settings.instance.schema:
         __tablename__ = f"{prefix}project_experiment"
 
         project_id: str = Field(foreign_key="core.project.id", primary_key=True)
-        experiment_id: str = Field(
-            foreign_key=f"{prefix}experiment.id", primary_key=True
-        )
+        experiment_id: str = Field(foreign_key="wetlab.experiment.id", primary_key=True)
 
     class DObjectExperiment(SQLModel, table=True):  # type: ignore
         """Links for `DObject` and `Experiment`."""
@@ -25,9 +23,7 @@ if "wetlab" in settings.instance.schema:
         __tablename__ = f"{prefix}dobject_experiment"
 
         dobject_id: str = Field(foreign_key="core.dobject.id", primary_key=True)
-        experiment_id: str = Field(
-            foreign_key=f"{prefix}experiment.id", primary_key=True
-        )
+        experiment_id: str = Field(foreign_key="wetlab.experiment.id", primary_key=True)
 
     class DObjectReadout(SQLModel, table=True):  # type: ignore
         """Links for `DObject` and `Readout`."""
@@ -35,17 +31,15 @@ if "wetlab" in settings.instance.schema:
         __tablename__ = f"{prefix}dobject_readout"
 
         dobject_id: str = Field(foreign_key="core.dobject.id", primary_key=True)
-        readout_id: str = Field(foreign_key=f"{prefix}readout.id", primary_key=True)
+        readout_id: str = Field(foreign_key="wetlab.readout.id", primary_key=True)
 
     class BiosampleTechsample(SQLModel, table=True):  # type: ignore
         """Links for `Biosample` and `Techsample`."""
 
         __tablename__ = f"{prefix}biosample_techsample"
 
-        biosample_id: str = Field(foreign_key=f"{prefix}biosample.id", primary_key=True)
-        techsample_id: str = Field(
-            foreign_key=f"{prefix}techsample.id", primary_key=True
-        )
+        biosample_id: str = Field(foreign_key="wetlab.biosample.id", primary_key=True)
+        techsample_id: str = Field(foreign_key="wetlab.techsample.id", primary_key=True)
 
     class DObjectBiosample(SQLModel, table=True):  # type: ignore
         """Links for `DObject` and `Biosample`."""
@@ -53,7 +47,7 @@ if "wetlab" in settings.instance.schema:
         __tablename__ = f"{prefix}dobject_biosample"
 
         dobject_id: str = Field(foreign_key="core.dobject.id", primary_key=True)
-        biosample_id: str = Field(foreign_key=f"{prefix}biosample.id", primary_key=True)
+        biosample_id: str = Field(foreign_key="wetlab.biosample.id", primary_key=True)
 
 else:
     ProjectExperiment = None  # type: ignore
