@@ -1,4 +1,4 @@
-import lnschema_core
+from lnschema_core import dev
 
 
 def biometa() -> str:
@@ -10,17 +10,17 @@ def biometa() -> str:
 
     21 characters (62**21=4e+37 possibilities) outperform UUID (2*122=5e+36).
     """
-    return lnschema_core.id.base62(n_char=21)
+    return dev.id.base62(n_char=21)
 
 
 def biosample() -> str:
     """Bio sample: 20 base62."""
-    return lnschema_core.id.base62(n_char=20)
+    return dev.id.base62(n_char=20)
 
 
 def techsample() -> str:
     """Tech sample: 20 base62."""
-    return lnschema_core.id.base62(n_char=20)
+    return dev.id.base62(n_char=20)
 
 
 def readout() -> str:
@@ -28,19 +28,19 @@ def readout() -> str:
 
     EFO ontology.
     """
-    return lnschema_core.id.base62(n_char=5)
+    return dev.id.base62(n_char=5)
 
 
 def experiment() -> str:
     """Experiments: 19 base62."""
-    return lnschema_core.id.base62(n_char=19)
+    return dev.id.base62(n_char=19)
 
 
 def experiment_type() -> str:
     """Experiments: 12 base62."""
-    return lnschema_core.id.base62(n_char=12)
+    return dev.id.base62(n_char=12)
 
 
 def treatment() -> str:
     """Projects: 12 base62."""
-    return lnschema_core.id.base62(n_char=12)
+    return dev.id.base62(n_char=12)
